@@ -1,7 +1,7 @@
 /* mbsupport.h --- Localize determination of whether we have multibyte stuff.
 
-   Copyright (C) 2004, 2005, 2007, 2009 Free Software Foundation, Inc.
-   
+   Copyright (C) 2004-2005, 2007, 2009-2010 Free Software Foundation, Inc.
+
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3, or (at your option)
@@ -22,7 +22,7 @@
    This gives us a consistent definition for all uses of MBS_SUPPORT. This
    follows the ``Don't Repeat Yourself'' principle from "The Pragmatic
    Programmer".
-  
+
    The tests should be *all* the ones that are needed for an individual
    application.  */
 
@@ -30,17 +30,7 @@
 #include <stdlib.h>
 #endif
 
-#if    defined(HAVE_ISWCTYPE) \
-    && defined(HAVE_LOCALE_H) \
-    && defined(HAVE_MBRLEN) \
-    && defined(HAVE_MBRTOWC) \
-    && defined(HAVE_WCHAR_H) \
-    && defined(HAVE_WCRTOMB) \
-    && defined(HAVE_WCSCOLL) \
-    && defined(HAVE_WCTYPE) \
-    && defined(HAVE_WCTYPE_H) \
-    && (defined(HAVE_STDLIB_H) && defined(MB_CUR_MAX)) \
-/* We can handle multibyte strings.  */
+#if defined(HAVE_WCSCOLL) && defined(HAVE_ISWCTYPE)
 # define MBS_SUPPORT 1
 #else
 # undef MBS_SUPPORT
